Other Resources
===============

* MongoDB:

  * `Official documents of MongoDB <http://docs.mongodb.org/manual/>`_
  * MongoDB official IRC channel:  **#mongodb** on **irc.freenode.net**

* PyMongo:

  * `Official documents of PyMongo <http://api.mongodb.org/python/current/index.html>`_
